The following pictures were used for Tile 1-5:

 * http://www.lifeofpix.com/wp-content/uploads/2015/03/Life-of-Pix-free-stock-photos-wood-house-garden-nature-finland-escoveries.jpg
 * http://www.lifeofpix.com/wp-content/uploads/2014/08/life-of-pix-free-stock-photos-Countryside-trees-hammock-chill-Relaxation.jpg
 * http://www.lifeofpix.com/wp-content/uploads/2014/09/life-of-pix-free-stock-photos-New-York-books-movies-Bookshop.jpg
 * http://www.lifeofpix.com/wp-content/uploads/2014/06/5-Life-Of-Pix-Free-Stock-Photo-street-little-market.jpg
 * https://stocksnap.io/photo/85D4IPPQ98
 * https://stocksnap.io/photo/79A4E09475

They were then shrunk to 12.5% from their original size and the canvas was
then limited to 300px.

These pictures are *Public Domain*. Please be sure to only use public domain
pictures as we can't ensure that attribution on the actual town sites is
shown.
